@@ -1,7 +1,8 @@
 package HTML::FormFu::Constraint::AllOrNone;
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-use strict;
-use base 'HTML::FormFu::Constraint::_others';
+with 'HTML::FormFu::Role::Constraint::Others';
 
 sub process {
     my ( $self, $params ) = @_;
@@ -58,6 +59,8 @@ sub constrain_value {
     return 1;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -78,15 +81,16 @@ Ensure that either all or none of the named fields are present.
 
 By default, if some but not all fields are submitted, errors are attached to 
 those fields which weren't submitted. This behaviour can be changed by setting 
-any of L</attach_errors_to_base>, L</attach_errors_to_others> or 
-L</attach_errors_to>.
+any of L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_base>,
+L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_others> or
+L<HTML::FormFu::Role::Constraint::Others/attach_errors_to>.
 
 This constraint doesn't honour the C<not()> value.
 
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from  
-L<HTML::FormFu::Constraint::_others>, L<HTML::FormFu::Constraint>
+L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
 
@@ -98,3 +102,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
