@@ -1,7 +1,8 @@
 package HTML::FormFu::Constraint::DependOn;
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-use strict;
-use base 'HTML::FormFu::Constraint::_others';
+with 'HTML::FormFu::Role::Constraint::Others';
 
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
@@ -73,6 +74,8 @@ sub _localize_args {
     return $self->parent->label;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -90,19 +93,22 @@ HTML::FormFu::Constraint::DependOn - Multi-field Dependency Constraint
 =head1 DESCRIPTION
 
 If a value is submitted for the field this constraint is attached to, then a 
-value must also be submitted for all fields named in L</others>.
+value must also be submitted for all fields named in
+L<HTML::FormFu::Role::Constraint::Others/others>.
 
-By default, if any of the named fields in L</others> are missing, an error 
-will be attached to each missing field. This behaviour can be changed by 
-setting any of L</attach_errors_to_base>, L</attach_errors_to_others> or 
-L</attach_errors_to>.
+By default, if any of the named fields in
+L<HTML::FormFu::Role::Constraint::Others/others> are missing, an error will be
+attached to each missing field. This behaviour can be changed by setting
+any of L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_base>,
+L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_others> or 
+L<HTML::FormFu::Role::Constraint::Others/attach_errors_to>.
 
 This constraint doesn't honour the C<not()> value.
 
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from  
-L<HTML::FormFu::Constraint::_others>, L<HTML::FormFu::Constraint>
+L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
 
@@ -114,3 +120,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
