@@ -8,9 +8,9 @@ with 'HTML::FormFu::Role::Element::Input';
 after BUILD => sub {
     my ( $self, $args ) = @_;
 
-    $self->field_type(    'button' );
-    $self->force_default( 1 );
-    
+    $self->field_type('button');
+    $self->force_default(1);
+
     return;
 };
 
@@ -39,8 +39,8 @@ L<HTML::FormFu::Element::Submit>
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
