@@ -17,8 +17,8 @@ has input_type => (
 );
 
 has reverse_group => (
-    is      => 'rw',
-    traits  => ['Chained'],
+    is     => 'rw',
+    traits => ['Chained'],
 );
 
 after BUILD => sub {
@@ -185,8 +185,7 @@ sub _string_field {
         else {
             $html .= sprintf
                 "<span%s>\n",
-                process_attrs( $option->{container_attributes} )
-                ;
+                process_attrs( $option->{container_attributes} );
 
             my $label = sprintf
                 "<label%s>%s</label>\n",
@@ -246,22 +245,22 @@ YAML config:
 Convenient to use group of checkbox fields.
 
 Use the same syntax as you would to create a Select element optgroup to 
-create Checkboxgroup sub-groups, see L<HTML::FormFu::Element::_Group/options> 
+create Checkboxgroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options> 
 for details.
 
 =head1 METHODS
 
 =head2 options
 
-See L<HTML::FormFu::Element::_Group/options>.
+See L<HTML::FormFu::Role::Element::Group/options>.
 
 =head2 values
 
-See L<HTML::FormFu::Element::_Group/values>.
+See L<HTML::FormFu::Role::Element::Group/values>.
 
 =head2 value_range
 
-See L<HTML::FormFu::Element::_Group/value_range>.
+See L<HTML::FormFu::Role::Element::Group/value_range>.
 
 =head2 auto_id
 
@@ -290,8 +289,8 @@ Default Value: C<true>
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Group>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Group>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
