@@ -16,12 +16,12 @@ our @DEFER_TO_SELECT = qw(
     value_range
 );
 
-for my $name ( @DEFER_TO_SELECT ) {
-    has $name => ( is => 'rw', traits  => ['Chained'] );
+for my $name (@DEFER_TO_SELECT) {
+    has $name => ( is => 'rw', traits => ['Chained'] );
 }
 
-has select => ( is => 'rw', traits  => ['Chained'], default => sub { {} } );
-has text   => ( is => 'rw', traits  => ['Chained'], default => sub { {} } );
+has select => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
+has text   => ( is => 'rw', traits => ['Chained'], default => sub { {} } );
 
 *default = \&value;
 
@@ -53,10 +53,10 @@ for my $method ( qw(
 
 after BUILD => sub {
     my ( $self, $args ) = @_;
-    
-    $self->multi_value( 1 );
-    $self->empty_first( 1 );
-    
+
+    $self->multi_value(1);
+    $self->empty_first(1);
+
     return;
 };
 
@@ -122,13 +122,13 @@ sub _combobox_defaults {
     my ($self) = @_;
 
     if ( defined( my $default = $self->default ) ) {
-        
+
         if ( !$self->form->submitted || $self->render_processed_value ) {
             for my $deflator ( @{ $self->_deflators } ) {
                 $default = $deflator->process($default);
             }
         }
-        
+
         my $select_options = $self->_elements->[0]->options;
 
         if ( $default ne ''
@@ -158,7 +158,8 @@ sub _add_select {
             name => $select_name,
         } );
 
-    apply_all_roles( $select_element, 'HTML::FormFu::Role::Element::MultiElement' );
+    apply_all_roles( $select_element,
+        'HTML::FormFu::Role::Element::MultiElement' );
 
     for my $method (@DEFER_TO_SELECT) {
         if ( defined( my $value = $self->$method ) ) {
@@ -192,7 +193,8 @@ sub _add_text {
             name => $text_name,
         } );
 
-    apply_all_roles( $text_element, 'HTML::FormFu::Role::Element::MultiElement' );
+    apply_all_roles( $text_element,
+        'HTML::FormFu::Role::Element::MultiElement' );
 
     if ( defined( my $default = $text->{default} ) ) {
         $text_element->default($default);
@@ -202,18 +204,18 @@ sub _add_text {
 }
 
 sub get_select_field_nested_name {
-    my ( $self ) = @_;
-    
+    my ($self) = @_;
+
     my $select_name = _build_field_name( $self, 'select' );
-    
-    return $self->get_element( { name => $select_name } )->nested_name
+
+    return $self->get_element( { name => $select_name } )->nested_name;
 }
 
 sub get_text_field_nested_name {
-    my ( $self ) = @_;
-    
+    my ($self) = @_;
+
     my $text_name = _build_field_name( $self, 'text' );
-    
+
     return $self->get_element( { name => $text_name } )->nested_name;
 }
 
@@ -326,23 +328,23 @@ selected. Otherwise, the Text field will use the value as its default.
 
 =head2 options
 
-See L<HTML::FormFu::Element::_Group/options> for details.
+See L<HTML::FormFu::Role::Element::Group/options> for details.
 
 =head2 values
 
-See L<HTML::FormFu::Element::_Group/values> for details.
+See L<HTML::FormFu::Role::Element::Group/values> for details.
 
 =head2 value_range
 
-See L<HTML::FormFu::Element::_Group/value_range> for details.
+See L<HTML::FormFu::Role::Element::Group/value_range> for details.
 
 =head2 empty_first
 
-See L<HTML::FormFu::Element::_Group/empty_first> for details.
+See L<HTML::FormFu::Role::Element::Group/empty_first> for details.
 
 =head2 empty_first_label
 
-See L<HTML::FormFu::Element::_Group/empty_first_label> for details.
+See L<HTML::FormFu::Role::Element::Group/empty_first_label> for details.
 
 =head2 select
 
@@ -373,7 +375,7 @@ L<constraint/constraints|HTML::FormFu/constraints>,
 L<inflator/inflators|HTML::FormFu/inflators>, 
 L<validator/validators|HTML::FormFu/validators> and 
 L<transformer/transformers|HTML::FormFu/transformers> is more like that of 
-a L<field element|HTML::FormFu::Element::_Field>, meaning all processors are 
+a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are 
 added directly to the date element, not to its child elements.
 
 This element's L<get_elements|HTML::FormFu/get_elements> and 
