@@ -20,8 +20,8 @@ has field_type => (
 after BUILD => sub {
     my ( $self, $args ) = @_;
 
-    $self->filename( 'content_button' );
-    
+    $self->filename('content_button');
+
     return;
 };
 
@@ -116,7 +116,7 @@ content_button form field, rendered using provided markup.
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
