@@ -1,5 +1,6 @@
 package HTML::FormFu::Element::Date;
 use Moose;
+use MooseX::Attribute::Chained;
 
 extends 'HTML::FormFu::Element::Multi';
 
@@ -62,26 +63,22 @@ for my $method ( qw(
 after BUILD => sub {
     my ( $self, $args ) = @_;
 
-    $self->printf_day(   '%d' );
-    $self->printf_month( '%d' );
-    $self->printf_year(  '%d' );
+    $self->printf_day('%d');
+    $self->printf_month('%d');
+    $self->printf_year('%d');
 
     $self->_known_fields( [qw( day month year )] );
 
     $self->field_order( [qw( day month year )] );
 
-    $self->day( {
-            prefix => [],
-        } );
+    $self->day( { prefix => [], } );
 
-    $self->month( {
-            prefix => [],
-        } );
+    $self->month( { prefix => [], } );
 
     $self->year( {
-            prefix => [],
-            less   => 0,
-            plus   => 10,
+            prefix  => [],
+            less    => 0,
+            plus    => 10,
             reverse => 0,
         } );
 
@@ -107,7 +104,8 @@ sub value {
 
                 my $printf_method = "printf_$field";
 
-                my $default = $value
+                my $default
+                    = $value
                     ? sprintf( $self->$printf_method, $self->$field->{default} )
                     : undef;
 
@@ -149,13 +147,13 @@ sub _date_defaults {
     my $default;
 
     if ( defined( $default = $self->default ) && length $default ) {
-        
+
         if ( !$self->form->submitted || $self->render_processed_value ) {
             for my $deflator ( @{ $self->_deflators } ) {
                 $default = $deflator->process($default);
             }
         }
-        
+
         my $is_blessed = blessed($default);
 
         if ( !$is_blessed || ( $is_blessed && !$default->isa('DateTime') ) ) {
@@ -167,7 +165,7 @@ sub _date_defaults {
     }
     elsif ( defined( $default = $self->default_natural ) ) {
         my $parser;
-        
+
         if ( defined( my $datetime_args = $self->default_datetime_args ) ) {
             if ( exists $datetime_args->{set_time_zone} ) {
                 my $tz = $datetime_args->{set_time_zone};
@@ -180,20 +178,20 @@ sub _date_defaults {
         else {
             $parser = DateTime::Format::Natural->new;
         }
-        $default = $parser->parse_datetime( $default );
+        $default = $parser->parse_datetime($default);
     }
     else {
-      $default = undef;
+        $default = undef;
     }
 
     if ( defined $default ) {
-        
+
         if ( defined( my $datetime_args = $self->default_datetime_args ) ) {
             for my $key ( keys %$datetime_args ) {
                 $default->$key( $datetime_args->{$key} );
             }
         }
-        
+
         for my $field ( @{ $self->field_order } ) {
             $self->$field->{default} = $default->$field;
         }
@@ -214,12 +212,20 @@ sub _add_day {
         ? @{ $day->{prefix} }
         : $day->{prefix};
 
+    if ( exists $day->{prefix_loc} ) {
+        @day_prefix
+            = ref $day->{prefix_loc}
+            ? map { $self->form->localize($_) } @{ $day->{prefix_loc} }
+            : $self->form->localize( $day->{prefix_loc} );
+    }
+
     @day_prefix = map { [ '', $_ ] } @day_prefix;
 
     my $element = $self->element( {
-            type    => 'Select',
-            name    => $day_name,
-            options => [ @day_prefix, map { [ $_, $_ ] } 1 .. 31 ],
+            type       => 'Select',
+            name       => $day_name,
+            options    => [ @day_prefix, map { [ $_, $_ ] } 1 .. 31 ],
+            attributes => $day->{attributes},
 
             defined $day->{default} ? ( default => $day->{default} ) : (),
         } );
@@ -243,14 +249,22 @@ sub _add_month {
         ? @{ $month->{prefix} }
         : $month->{prefix};
 
+    if ( exists $month->{prefix_loc} ) {
+        @month_prefix
+            = ref $month->{prefix_loc}
+            ? map { $self->form->localize($_) } @{ $month->{prefix_loc} }
+            : $self->form->localize( $month->{prefix_loc} );
+    }
+
     @month_prefix = map { [ '', $_ ] } @month_prefix;
 
     my $options = [ @month_prefix, map { [ $_ + 1, $months[$_] ] } 0 .. 11 ];
 
     my $element = $self->element( {
-            type    => 'Select',
-            name    => $month_name,
-            options => $options,
+            type       => 'Select',
+            name       => $month_name,
+            options    => $options,
+            attributes => $month->{attributes},
 
             defined $month->{default} ? ( default => $month->{default} ) : (),
         } );
@@ -286,12 +300,20 @@ sub _add_year {
         ? @{ $year->{prefix} }
         : $year->{prefix};
 
+    if ( exists $year->{prefix_loc} ) {
+        @year_prefix
+            = ref $year->{prefix_loc}
+            ? map { $self->form->localize($_) } @{ $year->{prefix_loc} }
+            : $self->form->localize( $year->{prefix_loc} );
+    }
+
     @year_prefix = map { [ '', $_ ] } @year_prefix;
 
     my $element = $self->element( {
-            type    => 'Select',
-            name    => $year_name,
-            options => [ @year_prefix, map { [ $_, $_ ] } @years ],
+            type       => 'Select',
+            name       => $year_name,
+            options    => [ @year_prefix, map { [ $_, $_ ] } @years ],
+            attributes => $year->{attributes},
 
             defined $year->{default} ? ( default => $year->{default} ) : (),
         } );
@@ -338,15 +360,15 @@ sub _build_month_list {
 
 sub _build_number_list {
     my ( $self, $start, $end, $interval ) = @_;
-    
+
     $interval ||= 1;
-    
+
     my @list;
-    
+
     for ( my $i = $start; $i <= $end; $i += $interval ) {
         push @list, $i;
     }
-    
+
     return @list;
 }
 
@@ -572,6 +594,20 @@ menu.
 Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
+=head3 prefix_loc
+
+Arguments: $localization_key
+
+Arguments: \@localization_keys
+
+A localized string or arrayref of localized strings to be inserted into the
+start of the select menu.
+
+Each value is localized and then only used as the label for a select item
+- the value for each of these items is always the empty string C<''>.
+
+Use C<prefix_loc> insted of C<prefix>.
+
 =head2 month
 
 Arguments: \%setting
@@ -598,6 +634,20 @@ menu.
 Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
+=head3 prefix_loc
+
+Arguments: $localization_key
+
+Arguments: \@localization_keys
+
+A localized string or arrayref of localized strings to be inserted into the
+start of the select menu.
+
+Each value is localized and then only used as the label for a select item
+- the value for each of these items is always the empty string C<''>.
+
+Use C<prefix_loc> insted of C<prefix>.
+
 =head3 names
 
 Arguments: \@months
@@ -641,6 +691,20 @@ menu.
 Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
+=head3 prefix_loc
+
+Arguments: $localization_key
+
+Arguments: \@localization_keys
+
+A localized string or arrayref of localized strings to be inserted into the
+start of the select menu.
+
+Each value is localized and then only used as the label for a select item
+- the value for each of these items is always the empty string C<''>.
+
+Use C<prefix_loc> insted of C<prefix>.
+
 =head3 list
 
 Arguments: \@years
@@ -708,7 +772,7 @@ L<constraint/constraints|HTML::FormFu/constraints>,
 L<inflator/inflators|HTML::FormFu/inflators>, 
 L<validator/validators|HTML::FormFu/validators> and 
 L<transformer/transformers|HTML::FormFu/transformers> is more like that of 
-a L<field element|HTML::FormFu::Element::_Field>, meaning all processors are 
+a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are 
 added directly to the date element, not to its select-menu child elements.
 
 This element's L<get_elements|HTML::FormFu/get_elements> and 
@@ -720,7 +784,7 @@ returns both itself and its child elements.
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element::Multi>, 
 L<HTML::FormFu::Element::Block>, 
 L<HTML::FormFu::Element>
