@@ -1,30 +1,36 @@
 package HTML::FormFu::Element::Fieldset;
 
-use strict;
-use base 'HTML::FormFu::Element::Block';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Element::Block';
+
+use HTML::FormFu::Util qw( xml_escape );
 
 __PACKAGE__->mk_output_accessors(qw( legend ));
 
-sub new {
-    my $self = shift->next::method(@_);
+__PACKAGE__->mk_attrs(qw( legend_attributes ));
+
+after BUILD => sub {
+    my $self = shift;
 
     $self->tag('fieldset');
 
-    return $self;
-}
+    return;
+};
 
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
-            legend => $self->legend,
+    my $render = $self->SUPER::render_data_non_recursive( {
+            legend            => $self->legend,
+            legend_attributes => xml_escape( $self->legend_attributes ),
             $args ? %$args : (),
         } );
 
     return $render;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -43,6 +49,17 @@ Fieldset element.
 
 =head1 METHODS
 
+=head2 legend
+
+If L</legend> is set, it is used as the fieldset's legend
+
+=head2 legend_loc
+
+Arguments: $localization_key
+
+To set the legend to a localized string, set L</legend_loc> to a key in 
+your L10N file instead of using L</legend>.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
@@ -59,3 +76,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
