@@ -1,14 +1,12 @@
 package HTML::FormFu::Element::Image;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::Button';
-use MRO::Compat;
-use mro 'c3';
+extends 'HTML::FormFu::Element::Button';
 
 __PACKAGE__->mk_attr_accessors(qw( src width height ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('image');
 
@@ -16,8 +14,10 @@ sub new {
         $self->src('');
     }
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -41,8 +41,8 @@ Image button form field.
 
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::Element::Button>, 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
