@@ -1,32 +1,34 @@
 package HTML::FormFu::Element::Number;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::Text';
-use Class::C3;
+extends 'HTML::FormFu::Element::Text';
+
+after BUILD => sub {
+    my $self = shift;
 
-sub new {
-    my $self = shift->next::method(@_);
-    
     $self->field_type('number');
-    
-    $self->deflator( 'FormatNumber' );
-    $self->filter(   'FormatNumber' );
-    
-    return $self;
-}
+
+    $self->deflator('FormatNumber');
+    $self->filter('FormatNumber');
+
+    return;
+};
 
 sub precision {
     my $self = shift;
-    
-    return $self->get_deflator({ type => 'FormatNumber' })->precision(@_);
+
+    return $self->get_deflator( { type => 'FormatNumber' } )->precision(@_);
 }
 
 sub trailing_zeroes {
     my $self = shift;
-    
-    return $self->get_deflator({ type => 'FormatNumber' })->trailing_zeroes(@_);
+
+    return $self->get_deflator( { type => 'FormatNumber' } )
+        ->trailing_zeroes(@_);
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
