@@ -1,20 +1,21 @@
 package HTML::FormFu::Element::Radio;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::Checkbox';
-use mro 'c3';
+extends 'HTML::FormFu::Element::Checkbox';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
 __PACKAGE__->mk_output_accessors(qw( default ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('radio');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -42,8 +43,8 @@ Overrides the default value, so it's C<true>.
 
 Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::Checkbox>, 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
