@@ -8,7 +8,7 @@ use HTML::FormFu::Util qw( DEBUG_PROCESS debug );
 use List::Util qw( first );
 use Carp qw( croak );
 
-has counter_name       => ( is => 'rw', traits => ['Chained'] );
+has counter_name => ( is => 'rw', traits => ['Chained'] );
 
 has _original_elements => ( is => 'rw' );
 
@@ -72,11 +72,11 @@ sub repeat {
     # If nested_name is *not* set, we add the repeatable counter to the names
     # of the child elements (leaves of the element tree).
     my $nested_name = $self->nested_name;
-    if (defined $nested_name && length $nested_name) {
-        return $self->_repeat_containing_block( $count );
+    if ( defined $nested_name && length $nested_name ) {
+        return $self->_repeat_containing_block($count);
     }
     else {
-        return $self->_repeat_child_elements( $count );
+        return $self->_repeat_child_elements($count);
     }
 }
 
@@ -89,7 +89,7 @@ sub _repeat_containing_block {
     # nested_name attribute of the Repeatable element, thus we extended
     # FF::Elements::_Field nested_names method to ignore Repeatable elements.
     my $nested_name = $self->nested_name;
-    $self->original_nested_name( $nested_name );
+    $self->original_nested_name($nested_name);
 
     # delimiter between nested_name and the incremented counter
     my $delimiter = $self->repeatable_delimiter;
@@ -97,6 +97,7 @@ sub _repeat_containing_block {
     my @return;
 
     for my $rep ( 1 .. $count ) {
+
         # create clones of elements and put them in a new block
         my @clones = map { $_->clone } @$children;
         my $block = $self->element('Block');
@@ -109,6 +110,7 @@ sub _repeat_containing_block {
         $block->repeatable_count($rep);
 
         if ( $self->increment_field_names ) {
+
             # store the original nested_name attribute for later usage when
             # building the original nested name
             $block->original_nested_name( $block->nested_name )
@@ -120,6 +122,7 @@ sub _repeat_containing_block {
             for my $field ( @{ $block->get_fields } ) {
 
                 if ( defined( my $name = $field->name ) ) {
+
                     # store original name for later usage when
                     # replacing the field names in constraints
                     $field->original_name($name)
@@ -127,7 +130,8 @@ sub _repeat_containing_block {
 
                     # store original nested name for later usage when
                     # replacing the field names in constraints
-                    $field->original_nested_name( $field->build_original_nested_name )
+                    $field->original_nested_name(
+                        $field->build_original_nested_name )
                         if !defined $field->original_nested_name;
                 }
             }
@@ -135,7 +139,9 @@ sub _repeat_containing_block {
 
         _reparent_children($block);
 
-        for my $field ( @{ $block->get_fields } ) {
+        my @fields = @{ $block->get_fields };
+
+        for my $field (@fields) {
             map { $_->parent($field) }
                 @{ $field->_deflators },
                 @{ $field->_filters },
@@ -147,60 +153,29 @@ sub _repeat_containing_block {
                 ;
         }
 
-        my $block_fields = $block->get_fields;
-
-        my @block_constraints = map { @{ $_->get_constraints } } @$block_fields;
-
-        # rename any 'others' fields
-        my @others_constraints = grep { defined $_->others }
-            grep { $_->can('others') } @block_constraints;
-
-        for my $constraint (@others_constraints) {
-            my $others = $constraint->others;
-            if ( !ref $others ) {
-                $others = [$others];
-            }
-            my @new_others;
-
-            for my $name (@$others) {
-                my $field
-                    = ( first { $_->original_nested_name eq $name }
-                    @$block_fields )
-                    || first { $_->original_name eq $name } @$block_fields;
-
-                if ( defined $field ) {
-                    push @new_others, $field->nested_name;
-                }
-                else {
-                    push @new_others, $name;
-                }
-            }
-
-            $constraint->others( \@new_others );
-        }
-
-        # rename any 'when' fields
-        my @when_constraints = grep { defined $_->when } @block_constraints;
-
-        for my $constraint (@when_constraints) {
-            my $when = $constraint->when;
-            my $name = $when->{field};
-
-            my $field
-                = first { $_->original_nested_name eq $name } @$block_fields;
-
-            if ( defined $field ) {
-                $when->{field} = $field->nested_name;
-            }
+        for my $field (@fields) {
+            map { $_->repeatable_repeat( $self, $block ) }
+                @{ $field->_constraints };
         }
 
         push @return, $block;
-
     }
 
     return \@return;
 }
 
+sub get_field_with_original_name {
+    my ( $self, $name, $fields ) = @_;
+
+    my $field = first { $_->original_nested_name eq $name }
+    grep { defined $_->original_nested_name } @$fields;
+
+    $field ||= first { $_->original_name eq $name }
+    grep { defined $_->original_name } @$fields;
+
+    return $field;
+}
+
 sub _repeat_child_elements {
     my ( $self, $count ) = @_;
 
@@ -231,14 +206,16 @@ sub _repeat_child_elements {
                     $field->original_nested_name( $field->nested_name )
                         if !defined $field->original_nested_name;
 
-                    $field->name(${name} . $delimiter . $rep);
+                    $field->name( ${name} . $delimiter . $rep );
                 }
             }
         }
 
         _reparent_children($block);
 
-        for my $field ( @{ $block->get_fields } ) {
+        my @fields = @{ $block->get_fields };
+
+        for my $field (@fields) {
             map { $_->parent($field) }
                 @{ $field->_deflators },
                 @{ $field->_filters },
@@ -250,71 +227,12 @@ sub _repeat_child_elements {
                 ;
         }
 
-        my $block_fields = $block->get_fields;
-
-        my @block_constraints = map { @{ $_->get_constraints } } @$block_fields;
-
-        # rename any 'others' fields
-        my @others_constraints = grep { defined $_->others }
-            grep { $_->can('others') } @block_constraints;
-
-        for my $constraint (@others_constraints) {
-            my $others = $constraint->others;
-            if ( !ref $others ) {
-                $others = [$others];
-            }
-            my @new_others;
-
-            for my $name (@$others) {
-                my $field
-                    = ( first { $_->original_nested_name eq $name }
-                    @$block_fields )
-                    || first { $_->original_name eq $name } @$block_fields;
-
-                if ( defined $field ) {
-                    push @new_others, $field->nested_name;
-                }
-                else {
-                    push @new_others, $name;
-                }
-            }
-
-            $constraint->others( \@new_others );
-        }
-
-        # rename any 'when' fields
-        my @when_constraints = grep { defined $_->when } @block_constraints;
-
-        for my $constraint (@when_constraints) {
-            my $when = $constraint->when;
-            my $name = $when->{field};
-
-            my $field
-                = first { $_->original_nested_name eq $name } @$block_fields;
-
-            if ( defined $field ) {
-                $when->{field} = $field->nested_name;
-            }
-        }
-
-        # rename any 'id_field' fields
-        my @id_field_constraints = grep { defined $_->id_field } 
-            grep { $_->can('id_field') } @block_constraints;
-
-        for my $constraint (@id_field_constraints) {
-            my $id_field = $constraint->id_field;
-            my $name = $id_field;
-
-            my $field
-                = first { $_->original_nested_name eq $name } @$block_fields;
-
-            if ( defined $field ) {
-                $constraint->id_field( $field->nested_name );
-            }
+        for my $field (@fields) {
+            map { $_->repeatable_repeat( $self, $block ) }
+                @{ $field->_constraints };
         }
 
         push @return, $block;
-
     }
 
     return \@return;
@@ -340,11 +258,13 @@ sub process {
     my $count        = 1;
 
     if ( defined $counter_name && defined $form->query ) {
+
         # are we in a nested-repeatable?
         my $parent = $self;
 
         while ( defined( $parent = $parent->parent ) ) {
-            my $field = $parent->get_field({ original_name => $counter_name });
+            my $field
+                = $parent->get_field( { original_name => $counter_name } );
 
             if ( defined $field ) {
                 $counter_name = $field->nested_name;
@@ -352,7 +272,7 @@ sub process {
             }
         }
 
-        my $input = $form->query->param( $counter_name );
+        my $input = $form->query->param($counter_name);
 
         if ( defined $input && $input =~ /^[1-9][0-9]*\z/ ) {
             $count = $input;
@@ -360,7 +280,7 @@ sub process {
     }
 
     if ( !$self->_original_elements ) {
-        DEBUG_PROCESS && debug("calling \$repeatable->count($count)");
+        DEBUG_PROCESS && debug("calling \$repeatable->repeat($count)");
 
         $self->repeat($count);
     }
@@ -462,7 +382,7 @@ inherits the Repeatable's display settings, such as L</attributes> and
 L</tag>.
 
 For all constraints attached to fields within a Repeatable block which use
-either L<others|HTML::FormFu::Constraint::_others/others> or
+either L<others|HTML::FormFu::Role::Constraint::Others/others> or
 L<when|HTML::FormFu::Constraint/when> containing names of fields within
 the same Repeatable block, when L<repeat> is called, those names will
 automatically be updated to the new nested-name for each field (taking
@@ -640,7 +560,7 @@ a setter.
 
 =head2 Unsupported Constraints
 
-Note that constraints with an L<others|HTML::FormFu::Constraint::_others> 
+Note that constraints with an L<others|HTML::FormFu::Role::Constraint::Others> 
 method do not work correctly within a Repeatable block. Currently, these are:
 L<AllOrNone|HTML::FormFu::Constraint::AllOrNone>, 
 L<DependOn|HTML::FormFu::Constraint::DependOn>, 
