@@ -35,8 +35,8 @@ Reset button form field.
 
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::Element::Button>, 
-L<HTML::FormFu::Element::_Input>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
