@@ -1,8 +1,8 @@
 package HTML::FormFu::Element::Select;
+use Moose;
+extends 'HTML::FormFu::Element';
 
-use strict;
-use base 'HTML::FormFu::Element::_Group';
-use mro 'c3';
+with 'HTML::FormFu::Role::Element::Group';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use HTML::FormFu::Util qw( append_xml_attribute process_attrs );
@@ -10,15 +10,15 @@ use List::MoreUtils qw( any );
 
 __PACKAGE__->mk_attr_accessors(qw( multiple size ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->filename('input');
     $self->field_filename('select_tag');
     $self->multi_value(1);
 
-    return $self;
-}
+    return;
+};
 
 sub _prepare_attrs {
     my ( $self, $submitted, $value, $default, $option ) = @_;
@@ -95,6 +95,8 @@ sub _string_field {
     return $html;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -119,36 +121,36 @@ YAML config:
 
 Select form field.
 
-Supports optgroups, see L<HTML::FormFu::Element::_Group/options> for 
+Supports optgroups, see L<HTML::FormFu::Role::Element::Group/options> for 
 details.
 
 =head1 METHODS
 
 =head2 options
 
-See L<HTML::FormFu::Element::_Group/options>.
+See L<HTML::FormFu::Role::Element::Group/options>.
 
 =head2 values
 
-See L<HTML::FormFu::Element::_Group/values>.
+See L<HTML::FormFu::Role::Element::Group/values>.
 
 =head2 value_range
 
-See L<HTML::FormFu::Element::_Group/value_range>.
+See L<HTML::FormFu::Role::Element::Group/value_range>.
 
 =head2 empty_first
 
-See L<HTML::FormFu::Element::_Group/empty_first>.
+See L<HTML::FormFu::Role::Element::Group/empty_first>.
 
 =head2 empty_first_label
 
-See L<HTML::FormFu::Element::_Group/empty_first_label>.
+See L<HTML::FormFu::Role::Element::Group/empty_first_label>.
 
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Group>, 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Group>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
