@@ -1,23 +1,26 @@
 package HTML::FormFu::Element::Textarea;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::_Field';
-use mro 'c3';
+extends "HTML::FormFu::Element";
+
+with 'HTML::FormFu::Role::Element::Field',
+    'HTML::FormFu::Role::Element::SingleValueField' =>
+    { -excludes => 'nested_name' };
 
 use HTML::FormFu::Util qw( process_attrs );
 
-__PACKAGE__->mk_attr_accessors(qw( cols rows ));
+__PACKAGE__->mk_attr_accessors(qw( cols rows placeholder ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->filename('input');
     $self->field_filename('textarea_tag');
     $self->cols(40);
     $self->rows(20);
 
-    return $self;
-}
+    return;
+};
 
 sub string {
     my ( $self, $args ) = @_;
@@ -49,10 +52,17 @@ sub _string_field {
 
     # textarea_tag template
 
-    my $html = sprintf qq{<textarea name="%s"%s>},
-        $render->{nested_name},
-        process_attrs( $render->{attributes} ),
-        ;
+    my $html .= "<textarea";
+
+    $html .= sprintf qq{ name="%s"}, $render->{nested_name};
+
+    if ( defined $self->placeholder ) {
+        $html .= sprintf qq{ placeholder="%s"}, $self->placeholder;
+    }
+
+    $html .= process_attrs( $render->{attributes} );
+
+    $html .= '>';
 
     if ( defined $render->{value} ) {
         $html .= $render->{value};
@@ -63,6 +73,8 @@ sub _string_field {
     return $html;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -89,10 +101,27 @@ Sets the C<textarea> tag's C<cols> attribute.
 
 Sets the C<textarea> tag's C<rows> attribute.
 
+=head2 placeholder
+
+Sets the HTML5 attribute C<placeholder> to the specified value.
+
+=head2 placeholder_xml
+
+If you don't want the C<placeholder> attribute to be XML-escaped, use the L</placeholder_xml> 
+method instead of L</placeholder>.
+
+Arguments: $string
+
+=head2 placeholder_loc
+
+Arguments: $localization_key
+
+Set the  C<placeholder> attribute using a L10N key.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::_Field>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
