@@ -8,40 +8,100 @@ use HTML::FormFu::Util qw(
 use Clone ();
 use List::MoreUtils qw( any none );
 
-has others                  => ( is => 'rw', traits  => ['Chained'] );
-has other_siblings          => ( is => 'rw', traits  => ['Chained'] );
-has attach_errors_to        => ( is => 'rw', traits  => ['Chained'] );
-has attach_errors_to_base   => ( is => 'rw', traits  => ['Chained'] );
-has attach_errors_to_others => ( is => 'rw', traits  => ['Chained'] );
+has others                  => ( is => 'rw', traits => ['Chained'] );
+has other_siblings          => ( is => 'rw', traits => ['Chained'] );
+has attach_errors_to        => ( is => 'rw', traits => ['Chained'] );
+has attach_errors_to_base   => ( is => 'rw', traits => ['Chained'] );
+has attach_errors_to_others => ( is => 'rw', traits => ['Chained'] );
 
 sub pre_process {
     my ($self) = @_;
-    
+
     if ( $self->other_siblings ) {
-        
+
         my $field = $self->field;
         my $block = $field;
-        
+
         # find the nearest parent that contains any field other than
         # the one this constraint is attached to
         while ( defined( my $parent = $block->parent ) ) {
             $block = $parent;
-            
+
             last if grep { $_ ne $field } @{ $block->get_fields };
         }
-        
+
         my @names;
-        
-        for my $sibling (@{ $block->get_fields }) {
+
+        for my $sibling ( @{ $block->get_fields } ) {
             next if $sibling == $field;
-            
+
             push @names, $sibling->nested_name;
         }
-        
-        $self->others([@names]);
+
+        $self->others( [@names] );
     }
 }
 
+after repeatable_repeat => sub {
+    my ( $self, $repeatable, $new_block ) = @_;
+
+    my $block_fields = $new_block->get_fields;
+
+    # rename any 'others' fields
+    {
+        my $others = $self->others;
+        if ( !ref $others ) {
+            $others = [$others];
+        }
+        my @new_others;
+
+        for my $name (@$others) {
+            my $field = $repeatable->get_field_with_original_name( $name,
+                $block_fields );
+
+            if ( defined $field ) {
+                DEBUG_CONSTRAINTS && debug(
+                    sprintf
+                        "Repeatable renaming constraint 'other' '%s' to '%s'",
+                    $name, $field->nested_name,
+                );
+
+                push @new_others, $field->nested_name;
+            }
+            else {
+                push @new_others, $name;
+            }
+        }
+
+        $self->others( \@new_others );
+    }
+
+    # rename any 'attach_errors_to' fields
+    if ( my $others = $self->attach_errors_to ) {
+        my @new_others;
+
+        for my $name (@$others) {
+            my $field = $repeatable->get_field_with_original_name( $name,
+                $block_fields );
+
+            if ( defined $field ) {
+                DEBUG_CONSTRAINTS && debug(
+                    sprintf
+                        "Repeatable renaming constraint 'attach_errors_to' '%s' to '%s'",
+                    $name, $field->nested_name,
+                );
+
+                push @new_others, $field->nested_name;
+            }
+            else {
+                push @new_others, $name;
+            }
+        }
+
+        $self->attach_errors_to( \@new_others );
+    }
+};
+
 sub mk_errors {
     my ( $self, $args ) = @_;
 
@@ -132,8 +192,8 @@ sub mk_errors {
 
 around clone => sub {
     my ( $orig, $self, $args ) = @_;
-    
-    my $clone = $self->$orig( $args );
+
+    my $clone = $self->$orig($args);
 
     if ( ref $self->others ) {
         $clone->others( Clone::clone( $self->others ) );
@@ -148,7 +208,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Constraint::_others - Base class for constraints needing others() method
+HTML::FormFu::Role::Constraint::Others - Base class for constraints needing others() method
 
 =head1 METHODS
 
