@@ -1,32 +1,21 @@
 package HTML::FormFu::Upload;
+use Moose;
+use MooseX::Attribute::Chained;
+
+with 'HTML::FormFu::Role::Populate';
 
-use strict;
 use Carp qw( croak );
 
-use HTML::FormFu::Attribute qw( mk_item_accessors );
-use HTML::FormFu::ObjectUtil qw( form parent populate );
+use HTML::FormFu::ObjectUtil qw( form parent );
 use HTML::FormFu::UploadParam;
 use Scalar::Util qw( reftype );
 
-__PACKAGE__->mk_item_accessors(qw( headers filename size type ));
+has headers  => ( is => 'rw', traits => ['Chained'] );
+has filename => ( is => 'rw', traits => ['Chained'] );
+has size     => ( is => 'rw', traits => ['Chained'] );
+has type     => ( is => 'rw', traits => ['Chained'] );
 
-sub new {
-    my $class = shift;
-    my %attrs;
-    
-    if (@_) {
-        croak "attributes argument must be a hashref"
-            if reftype( $_[0] ) ne 'HASH';
-        
-        %attrs = %{ $_[0] };
-    }
-
-    my $self = bless \%attrs, $class;
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+sub BUILD { }
 
 sub _param {
     my ( $self, $param ) = @_;
@@ -42,6 +31,22 @@ sub _param {
     return defined $self->{_param} ? $self->{_param}->param : ();
 }
 
+sub slurp {
+    my ($self) = @_;
+
+    my $fh = $self->fh;
+
+    return if !defined $fh;
+
+    binmode $fh;
+
+    local $/;
+
+    return <$fh>;
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -71,12 +76,12 @@ from L<HTML::FormFu::Upload>:
 
 =head2 parent
 
-Returns the L<field|HTML::FormFu::Element::_Field> object that the constraint 
-is associated with.
+Returns the L<field|HTML::FormFu::Role::Element::Field> object that the upload
+object is associated with.
 
 =head2 form
 
-Returns the L<HTML::FormFu> object that the constraint's field is attached 
+Returns the L<HTML::FormFu> object that the upload object's field is attached 
 to.
 
 =head2 populate
@@ -95,3 +100,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
