@@ -4,7 +4,7 @@ use strict;
 
 use HTML::FormFu::Constants qw( $SPACE );
 use HTML::FormFu::Literal;
-use Scalar::Util qw( blessed );
+use Scalar::Util qw( blessed reftype );
 use Readonly;
 use Exporter qw/ import /;
 use Carp qw/ croak /;
@@ -69,7 +69,10 @@ sub debug {
             my $key   = shift;
             my $value = shift;
 
-            if ( ref $value ) {
+            if ( !defined $value ) {
+                $value = "is undef\n";
+            }
+            elsif ( ref $value ) {
                 $value = Data::Dumper::Dumper($value);
                 $value =~ s/^\$VAR1 = //;
             }
@@ -109,12 +112,11 @@ sub _filter_components {
 
         my $value;
 
-        @$components
-            = grep {
+        @$components = grep {
                    $_->can($name)
                 && defined( $value = $_->$name )
                 && $value eq $args->{$name}
-            } @$components;
+        } @$components;
     }
 
     return $components;
@@ -129,7 +131,10 @@ sub _get_elements {
         @$elements = grep {
                    $_->can($name)
                 && defined( $value = $_->$name )
-                && (ref($args->{$name}) eq 'Regexp' ? $value =~ $args->{$name} : $value eq $args->{$name})
+                && (
+                ref( $args->{$name} ) eq 'Regexp'
+                ? $value =~ $args->{$name}
+                : $value eq $args->{$name} )
         } @$elements;
     }
 
@@ -368,7 +373,6 @@ sub require_class {
         eval { require $class };
         croak $@ if $@;
 
-        Class::C3::initialize();
     }
 
     return;
@@ -418,8 +422,8 @@ sub literal {
 sub process_attrs {
     my ($attrs) = @_;
 
-    eval { my %attrs = %$attrs };
-    croak 'argument to process_attrs() must be a hashref' if $@;
+    croak 'argument to process_attrs() must be a hashref'
+        if reftype($attrs) ne 'HASH';
 
     my @attribute_parts;
 
@@ -494,19 +498,56 @@ sub _merge_hashes {
 
     my %merged = %$lefthash;
 
-    while ( my ( $key, $value ) = each %$righthash ) {
-        my $is_right_ref = ref $value eq 'HASH';
-        my $is_left_ref = exists $lefthash->{$key} && ref $value eq 'HASH';
+    while ( my ( $key, $right_value ) = each %$righthash ) {
 
-        if ( $is_left_ref && $is_right_ref ) {
-            $merged{$key} = _merge_hashes( $lefthash->{$key}, $value );
+        my $left_value = $lefthash->{$key};
+
+        if ( exists $lefthash->{$key} ) {
+
+            my $is_left_ref = exists $lefthash->{$key}
+                && ref $lefthash->{$key} eq 'HASH';
+
+            if ( ref $left_value eq 'HASH' && ref $right_value eq 'ARRAY' ) {
+                $merged{$key} = _merge_hash_array( $left_value, $right_value );
+            }
+            elsif ( ref $left_value eq 'ARRAY' && ref $right_value eq 'HASH' ) {
+                $merged{$key} = _merge_array_hash( $left_value, $right_value );
+            }
+            elsif ( ref $left_value eq 'ARRAY' && ref $right_value eq 'ARRAY' )
+            {
+                $merged{$key} = _merge_array_array( $left_value, $right_value );
+            }
+            elsif ( ref $left_value eq 'HASH' && ref $right_value eq 'HASH' ) {
+                $merged{$key} = _merge_hashes( $left_value, $right_value );
+            }
+            else {
+                $merged{$key} = $right_value;
+            }
         }
         else {
-            $merged{$key} = $value;
+            $merged{$key} = $right_value;
         }
     }
 
     return \%merged;
 }
 
+sub _merge_hash_array {
+    my ( $left, $right ) = @_;
+
+    return [ $left, @$right ];
+}
+
+sub _merge_array_hash {
+    my ( $left, $right ) = @_;
+
+    return [ @$left, $right ];
+}
+
+sub _merge_array_array {
+    my ( $left, $right ) = @_;
+
+    return [ @$left, @$right ];
+}
+
 1;
