@@ -1,8 +1,7 @@
 package HTML::FormFu::Validator;
 
-use strict;
-use base 'HTML::FormFu::Processor';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Validator;
 use Scalar::Util qw( reftype blessed );
@@ -15,7 +14,7 @@ sub process {
 
     my @errors;
 
-    if ( ( reftype( $value ) || '' ) eq 'ARRAY' ) {
+    if ( ( reftype($value) || '' ) eq 'ARRAY' ) {
         push @errors, eval { $self->validate_values( $value, $params ) };
 
         if ($@) {
@@ -66,6 +65,8 @@ sub return_error {
     return $err;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -136,3 +137,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
